@@ -589,7 +589,8 @@ class DataBase():
         :param attrs: [opt] Attributes to put in the VI.
         """
         if variable in self.variables:
-            log.warning('%s already in variables, it will be overwritten.')
+            log.warning('%s already in variables, it will be overwritten.',
+                        variable)
 
         if dims is None:
             dims = self.vi.get_attribute_param(variable, 'dims', None)
@@ -645,7 +646,7 @@ def guess_dimensions(db: 'DataDisk', var: str):
         krg.make_str_idx(var=db.avail.var)
         dims_fg = []
         for fg in db.filegroups:
-            cmd = fg.get_fg_keyrings(krg)
+            cmd = fg.get_fg_keyrings(krg, krg.copy())
             if cmd is not None:
                 key = cmd.infile['var']
                 key.make_list_int()
@@ -663,15 +664,17 @@ def guess_dimensions(db: 'DataDisk', var: str):
 
     log.debug('Guessed dimensions %s for variable %s', dims, var)
 
-    warn = False
     for d in db.coords:
+        warn = False
         if d not in dims:
             for fg in db.filegroups:
                 if fg.cs[d].shared:
                     warn = True
 
-    if warn:
-        log.warning(("'%s' dimension is shared, but not in guess (%s), "
-                     "something might be wrong"), d, dims)
+        if warn:
+            log.warning(("'%s' dimension is shared, but not present in the "
+                         "guess for variable '%s' (%s) "
+                         "something might be wrong"),
+                        d, var, dims)
 
     return dims
