@@ -42,7 +42,9 @@ class FilegroupLoad(FilegroupScan):
 
         :returns: False if nothing was loaded, True otherwise.
         """
-        cmd = self.get_fg_keyrings(keyring)
+        memory = Keyring(**{d: list(range(k.size))
+                            for d, k in keyring.items()})
+        cmd = self.get_fg_keyrings(keyring, memory)
         if cmd is None:
             return False
         self.load(*cmd)
@@ -70,34 +72,40 @@ class FilegroupLoad(FilegroupScan):
 
         self.do_post_loading(keyring)
 
-    def get_fg_keyrings(self, keyring: Keyring) -> Optional[CmdKeyrings]:
+    def get_fg_keyrings(self, infile: Keyring,
+                        memory: Keyring) -> Optional[CmdKeyrings]:
         """Get filegroup specific keyring.
 
         Use `contains` attribute to translate keyring acting on available scope
         to acting on the filegroup alone.
 
-        :param keyring: Keyring acting on database available scope.
+        :param infile: Keyring acting on database available scope.
+        :param memory: Keyring acting on database loaded scope.
         :returns: Infile and memory keyrings for this filegroup.
             None if there is nothing to load in this filegroup.
         """
         krg_infile = Keyring()
         krg_memory = Keyring()
 
-        for dim, key in keyring.items_values():
+        for dim, key in infile.items_values():
             if dim not in self.cs:
                 continue
-            infile = np.array(self.contains[dim][key])
-            memory = np.arange(infile.size)
+            indices_inf = np.array(self.contains[dim][key])
+            indices_mem = np.array(memory[dim].as_list())
 
-            none = np.where(np.equal(infile, None))[0]
-            infile = np.delete(infile, none)
-            memory = np.delete(memory, none)
+            if indices_inf.size != indices_mem.size:
+                raise IndexError(f"Infile and memory keys for {dim} have "
+                                 "different sizes.")
 
-            if len(infile) == 0:
+            none = np.where(np.equal(indices_inf, None))[0]
+            indices_inf = np.delete(indices_inf, none)
+            indices_mem = np.delete(indices_mem, none)
+
+            if len(indices_inf) == 0:
                 return None
 
-            krg_infile[dim] = infile
-            krg_memory[dim] = memory
+            krg_infile[dim] = indices_inf
+            krg_memory[dim] = indices_mem
 
         krg_infile.simplify()
         krg_memory.simplify()
@@ -161,7 +169,8 @@ class FilegroupLoad(FilegroupScan):
                 self._sort_memory(keyrings)
 
                 inf, mem = keyrings
-                if not inf.is_shape_equivalent(mem.subset(inf)):
+                keys = set(inf) & set(mem)
+                if not inf.subset(keys).is_shape_equivalent(mem.subset(keys)):
                     raise IndexError("Infile and memory keyrings have different"
                                      f" shapes ({cmd})")
 
@@ -191,7 +200,7 @@ class FilegroupLoad(FilegroupScan):
                 raise KeyError(f"A None key was issued for '{dim}' "
                                "dimension which is present in file.")
 
-        order = ['var'] + order_inf
+        order = ['var'] + list(order_inf)
         keyrings.set(inf.subset(order), keyrings.memory)
 
     def _sort_memory(self, keyrings: CmdKeyrings):
@@ -474,8 +483,11 @@ class FilegroupLoad(FilegroupScan):
         if kwargs is None:
             kwargs = {}
 
+        memory = keyring.copy()
+        memory['var'] = var
         keyring['var'] = self.db.avail.var.get_str_index(sibling)
-        cmd = self.get_fg_keyrings(keyring)
+
+        cmd = self.get_fg_keyrings(keyring, memory)
         if cmd is None:
             return False
 
@@ -483,17 +495,8 @@ class FilegroupLoad(FilegroupScan):
 
         for cmd in commands:
             for cks in cmd:
-                # keyring argument dictates command shape
-                # help user to match `krg_inf` and `dimensions`
-                for name, input_key in keyring.items():
-                    if input_key.size == 0:
-                        cks.infile[name].make_list_int()
-                        cks.memory[name].make_list_int()
-                    else:
-                        cks.infile[name].make_int_list()
-                        cks.memory[name].make_int_list()
-                cks.memory['var'] = var
                 cks.infile['var'] = self._get_infile_name(var)
+                cks.infile.limit(cks.memory)
             log.debug('Command: %s', cmd)
 
             file = self.open_file(cmd.filename, mode='r+', log_lvl='info')
